<?php

/*
 * kohinos_cooperatic
 * Copyright (C) 2019-2020  ADML63
 * Copyright (C) 2020- Cooperatic
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
namespace App\Admin;

use App\Entity\Adherent;
use App\Entity\GlobalParameter;
use App\Entity\User;
use App\Entity\Flux;
use Sonata\AdminBundle\Datagrid\DatagridMapper;
use Sonata\AdminBundle\Datagrid\ListMapper;
use Sonata\AdminBundle\Form\FormMapper;
use Sonata\AdminBundle\Route\RouteCollection;
use Sonata\AdminBundle\Show\ShowMapper;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\Extension\Core\Type\HiddenType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\MoneyType;

/**
 * Administration des cotisations des adhérents
 *
 * KOHINOS : Outil de gestion de Monnaie Locale Complémentaire
 * @author Julien Jorry <julien.jorry@gmail.com>
 */
class CotisationAdherentAdmin extends CotisationAdmin
{
    protected $baseRouteName = 'cotisation_adherent';
    protected $baseRoutePattern = 'cotisation_adherent';

    public function configure()
    {
        parent::configure();
    }

    /**
    * {@inheritdoc}
    */
    public function createQuery($context = 'list')
    {
        $user = $this->security->getUser();
        $query = parent::createQuery($context);
        $query->leftJoin($query->getRootAliases()[0] . '.operateur', 'u')
              ->andWhere($query->getRootAliases()[0] .".type='cotisation_adherent'")
              // ->andWhere('u.adherent IS NOT NULL')
        ;
        if (empty($this->getRequest()->getSession()->get('_groupegere'))) {
            if ($user->isGranted('ROLE_GESTION_GROUPE') || $user->isGranted('ROLE_CONTACT') || $user->isGranted('ROLE_TRESORIER')) {
                $query->andWhere('false = true');
            }
        } else {
            $groupe = $this->getRequest()->getSession()->get('_groupegere');
            $em = $this->getConfigurationPool()->getContainer()->get('doctrine')->getManager();
            $adhTable =  $em->getMetadataFactory()->getMetadataFor(Adherent::class)->getTableName();
            $fluxTable =  $em->getMetadataFactory()->getMetadataFor(Flux::class)->getTableName();
            $connection = $em->getConnection();
            $statement = $connection->prepare("SELECT f.id FROM $fluxTable f INNER JOIN $adhTable a ON (a.id = f.adherent_id OR a.id = f.adherent_dest_id) WHERE a.groupe_id = :groupe_id");
            $statement->bindValue(':groupe_id', $groupe->getId());
            $statement->execute();
            $ids = $statement->fetchAll();
            $query
                ->andWhere($query->expr()->in($query->getRootAliases()[0].'.id', ':ids'))
                ->setParameter('ids', $ids)
            ;
        }
        return $query;
    }

    /**
    * {@inheritdoc}
    */
    protected function configureShowFields(ShowMapper $showMapper)
    {
        parent::configureShowFields($showMapper);
    }

    /**
    * {@inheritdoc}
    */
    protected function configureDatagridFilters(DatagridMapper $datagridMapper): void
    {
        parent::configureDatagridFilters($datagridMapper);
        $datagridMapper
            ->add('expediteur', null, array('label' => 'Adhérent'))
        ;
    }

    /**
    * {@inheritdoc}
    */
    protected function configureFormFields(FormMapper $formMapper): void
    {
        $em = $this->getConfigurationPool()->getContainer()->get('doctrine')->getManager();
        $cotisation = $this->getSubject();
        $expediteurInfos = array(
            'label' => 'Expéditeur',
            'class' => Adherent::class,
            'choices' =>  $em->getRepository(Adherent::class)->findOrderByName(),
            'placeholder' => 'Choisir un adhérent',
            'required' => true,
        );
        $exp = $this->getRequest()->get('expediteur');
        if (!empty($exp)) {
            $expediteurInfos['data'] = $em->getRepository(Adherent::class)->findOneById($exp);
        }
        $formMapper
            ->with('Cotisation', ['class' => 'col-md-8'])
                ->add('montant', MoneyType::class, array(
                    'label' => 'Montant',
                    'data' => ($cotisation->getMontant() != null)?$cotisation->getMontant():floatval($em->getRepository(GlobalParameter::class)->val(GlobalParameter::COTISATION_ADHERENT)),
                    'help' => 'Montant par défaut des cotisations adhérent : '.floatval($em->getRepository(GlobalParameter::class)->val(GlobalParameter::COTISATION_ADHERENT))
                ))
                ->add('reference', TextType::class, array(
                    'required' => false
                ))
                ->add('expediteur', EntityType::class, $expediteurInfos)
            ->end()
        ;
        parent::configureFormFields($formMapper);
    }

    /**
    * {@inheritdoc}
    */
    protected function configureRoutes(RouteCollection $collection)
    {
        parent::configureRoutes($collection);
    }

    /**
    * {@inheritdoc}
    */
    protected function configureListFields(ListMapper $listMapper): void
    {
        unset($this->listModes['mosaic']);
        $listMapper
            ->addIdentifier('expediteur', null, array(
                'label' => 'Adherent'
            ))
        ;
        parent::configureListFields($listMapper);
    }
}
